==> isotoma.recipe.depcheck-0.0.0.tar.gz: isotoma.recipe.depcheck-0.0.0/isotoma/recipe/depcheck/__init__.py <==
# Copyright 2010 Isotoma Limited
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import stat

class DependencyError(Exception): pass

class Depcheck(object):

    def __init__(self, buildout, name, options):
        self.name = name
        self.options = options
        self.buildout = buildout
        self.options.setdefault("locale-file", "/var/lib/locales/supported.d/local")

    def install(self):
        for e in self.options.get('executable', '').strip().split():
            e = e.strip()
            if not os.path.exists(e):
                raise DependencyError("Dependency %s does not exist" % e)
            mode = os.stat(e)[stat.ST_MODE]
            if not stat.S_IXOTH & mode:
                raise DependencyError("Dependency %s is not executable" % e)
        locales = [x.split(" ",1)[0] for x in open(self.options["locale-file"]).read().split("\n")]
        for l in self.options.get("locale", '').strip().split():
            l = l.strip()
            if l not in locales:
                raise DependencyError("Missing locale %s from system" % l)
        return []

    def update(self):
        pass

==> isotoma.recipe.depcheck-0.0.1.tar.gz: isotoma.recipe.depcheck-0.0.1/isotoma/recipe/depcheck/__init__.py <==
# Copyright 2010 Isotoma Limited
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import stat

class DependencyError(Exception): pass

class Depcheck(object):

    def __init__(self, buildout, name, options):
        self.name = name
        self.options = options
        self.buildout = buildout
        self.options.setdefault("locale-file", "/var/lib/locales/supported.d/local")

    def install(self):
        for e in self.options.get('executable', '').strip().split():
            e = e.strip()
            if not os.path.exists(e):
                raise DependencyError("Dependency %s does not exist" % e)
            mode = os.stat(e)[stat.ST_MODE]
            if not stat.S_IXOTH & mode:
                raise DependencyError("Dependency %s is not executable" % e)
        for d in self.options.get('directory', '').strip().split():
            d = d.strip()
            if not os.path.isdir(d):
                raise DependencyError("Dependency %s is not a directory" % d)
        for f in self.options.get('file', '').strip().split():
            f = f.strip()
            if not os.path.isfile(f):
                raise DependencyError("Dependency %s is not a file" % f)
        locales = [x.split(" ",1)[0] for x in open(self.options["locale-file"]).read().split("\n")]
        for l in self.options.get("locale", '').strip().split():
            l = l.strip()
            if l not in locales:
                raise DependencyError("Missing locale %s from system" % l)
        return []

    def update(self):
        pass
